==> haskell-unordered-containers-0.2.20-70-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unordered-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 unordered-containers
version:              0.2.20
visibility:           public
id:                   unordered-containers-0.2.20-Asw2mvs6LgrELNyeUEam3W
key:                  unordered-containers-0.2.20-Asw2mvs6LgrELNyeUEam3W
license:              BSD-3-Clause
copyright:
    2010-2014 Johan Tibell
    2010 Edward Z. Yang

maintainer:           simon.jakobi@gmail.com, David.Feuer@gmail.com
author:               Johan Tibell
homepage:
    https://github.com/haskell-unordered-containers/unordered-containers

synopsis:             Efficient hashing-based container types
description:
    Efficient hashing-based container types.  The containers have been
    optimized for performance critical use, both in terms of large data
    quantities and high speed.

    The declared cost of each operation is either worst-case or
    amortized, but remains valid even if structures are shared.

    /Security/

    This package currently provides no defenses against hash collision attacks
    such as HashDoS.
    Users who need to store input from untrusted sources are advised to use
    @Data.Map@ or @Data.Set@ from the @containers@ package instead.

category:             Data
abi:                  4ec8a03feb883a71efb341c58f11833d
exposed:              True
exposed-modules:
    Data.HashMap.Internal Data.HashMap.Internal.Array
    Data.HashMap.Internal.Debug Data.HashMap.Internal.List
    Data.HashMap.Internal.Strict Data.HashMap.Lazy Data.HashMap.Strict
    Data.HashSet Data.HashSet.Internal

import-dirs:          /usr/lib/ghc-9.4.8/site-local/unordered-containers-0.2.20
library-dirs:         /usr/lib/ghc-9.4.8/site-local/unordered-containers-0.2.20
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/unordered-containers-0.2.20
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unordered-containers
hs-libraries:         HSunordered-containers-0.2.20-Asw2mvs6LgrELNyeUEam3W
depends:
    base-4.17.2.1 deepseq-1.4.8.0
    hashable-1.4.4.0-D3M5e9EeJxCJTqzfO7ugwa template-haskell-2.19.0.0

haddock-interfaces:
    /usr/share/doc/haskell-unordered-containers/html/unordered-containers.haddock

haddock-html:         /usr/share/doc/haskell-unordered-containers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unordered-containers-0.2.20-72-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unordered-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 unordered-containers
version:              0.2.20
visibility:           public
id:                   unordered-containers-0.2.20-2eRdi4Eno3wAApPXuoC33k
key:                  unordered-containers-0.2.20-2eRdi4Eno3wAApPXuoC33k
license:              BSD-3-Clause
copyright:
    2010-2014 Johan Tibell
    2010 Edward Z. Yang

maintainer:           simon.jakobi@gmail.com, David.Feuer@gmail.com
author:               Johan Tibell
homepage:
    https://github.com/haskell-unordered-containers/unordered-containers

synopsis:             Efficient hashing-based container types
description:
    Efficient hashing-based container types.  The containers have been
    optimized for performance critical use, both in terms of large data
    quantities and high speed.

    The declared cost of each operation is either worst-case or
    amortized, but remains valid even if structures are shared.

    /Security/

    This package currently provides no defenses against hash collision attacks
    such as HashDoS.
    Users who need to store input from untrusted sources are advised to use
    @Data.Map@ or @Data.Set@ from the @containers@ package instead.

category:             Data
abi:                  b911ca3332962ad5806e359fff3a1b4c
exposed:              True
exposed-modules:
    Data.HashMap.Internal Data.HashMap.Internal.Array
    Data.HashMap.Internal.Debug Data.HashMap.Internal.List
    Data.HashMap.Internal.Strict Data.HashMap.Lazy Data.HashMap.Strict
    Data.HashSet Data.HashSet.Internal

import-dirs:          /usr/lib/ghc-9.4.8/site-local/unordered-containers-0.2.20
library-dirs:         /usr/lib/ghc-9.4.8/site-local/unordered-containers-0.2.20
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/unordered-containers-0.2.20
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unordered-containers
hs-libraries:         HSunordered-containers-0.2.20-2eRdi4Eno3wAApPXuoC33k
depends:
    base-4.17.2.1 deepseq-1.4.8.0
    hashable-1.4.4.0-HayYj9uqgN4KUEsvzi6aVt template-haskell-2.19.0.0

haddock-interfaces:
    /usr/share/doc/haskell-unordered-containers/html/unordered-containers.haddock

haddock-html:         /usr/share/doc/haskell-unordered-containers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
